"use client";

import { useId } from "react";

import { useTranslations } from "next-intl";
import { Controller } from "react-hook-form";

import { cn } from "@/lib/utils";

import { InputFieldProps } from "../types/all-fields";

type InputVariant =
	| "default"
	| "outline"
	| "ghost"
	| "transparent"
	| "under_line";
// type InputSize = "sm" | "md" | "lg";

const variantStyles: Record<InputVariant, string> = {
	default: "hover:bg-accent border border-input bg-background",
	outline: "border-2 border-gray-300 bg-transparent",
	ghost: "border-none bg-gray-100",
	transparent: "border-none bg-transparent",
	under_line: "rounded-none bg-transparent  border-b border-primary ",
};

// const sizeStyles: Record<InputSize, string> = {
//   sm: "px-2 py-1 text-sm",
//   md: "px-3 py-2 text-base",
//   lg: "px-4 py-3 text-lg",
// };

const OtpField = <T,>({
	name,
	control,
	label,
	hidden = false,
	required = false,
	containerClassName,
	inputClassName,
	labelClassName,
	errorClassName,
	variant = "default",
	placeholder,
}: InputFieldProps<T>) => {
	const id = useId();
	const t = useTranslations();

	return (
		<Controller
			name={name}
			control={control}
			render={({ field, fieldState: { error } }) => (
				<div
					className={cn(
						"col-span-12 p-2",
						{ hidden: hidden },
						containerClassName
					)}
				>
					<label
						htmlFor={id}
						className={cn(
							"mb-1 block text-sm font-medium text-gray-700",
							labelClassName
						)}
					>
						{label || name}
						{required && <span className="ml-1 text-red-500">{"*"}</span>}
					</label>

					<div dir="ltr">
						{/*<InputOTP
							placeholder={placeholder || t("Validation.Placeholder.Phone")}
							className={cn(variantStyles[variant], inputClassName)}
							maxLength={4}
							{...field}
						/>*/}
					</div>
					{error && (
						<span
							className={cn("-bottom-6 text-sm text-red-500", errorClassName)}
						>
							{error.message}
						</span>
					)}
				</div>
			)}
		/>
	);
};

export default OtpField;
